@@ -5,7 +5,7 @@
 //!
 //! ```toml
 //! [dependencies]
-//! simple-uuid = { version = "*", features = ["random"] }
+//! simple-uuid = { version = "*", features = ["rand_num"] }
 //! ```
 //!
 //! ```rust
@@ -13,6 +13,7 @@
 //! println!("{}", v4!());
 //! ```
 #![doc(html_root_url = "https://docs.rs/simple-uuid")]
+#![feature(doc_cfg)]
 
 mod name;
 mod random;
@@ -168,7 +169,7 @@ pub struct TimeStamp(u64);
 
 impl TimeStamp {
     /// Generate new UTC timestamp.
-    pub fn new_ts() -> u64 {
+    pub fn new() -> u64 {
         let utc = SystemTime::now()
             .duration_since(SystemTime::UNIX_EPOCH)
             .unwrap()
@@ -334,15 +335,6 @@ impl ToString for Node {
     }
 }
 
-pub struct Random(u128);
-
-pub enum Algo {
-    MD5,
-    SHA1,
-}
-
-pub struct Hash;
-
 #[cfg(test)]
 mod tests {
     use super::*;
